==> qgis_3.10.14+dfsg.orig.tar.xz: qgis-3.10.14/src/providers/wms/qgstilescalewidget.h <==
/***************************************************************************
    qgstilescalewidget.cpp  - slider to choose wms-c resolutions
                             -------------------
    begin    : 28 Mar 2010
    copyright: (C) 2010 Juergen E. Fischer < jef at norbit dot de >

 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QGSTILESCALEWIDGET_H
#define QGSTILESCALEWIDGET_H

#include "ui_qgstilescalewidgetbase.h"

class QgsMapCanvas;
class QgsMapLayer;
class QMainWindow;

class QgsTileScaleWidget : public QWidget, private Ui::QgsTileScaleWidget
{
    Q_OBJECT

  public:
    static void showTileScale( QMainWindow *mainWindow );

  public slots:
    void layerChanged( QgsMapLayer *layer );
    void scaleChanged( double );
    void mSlider_valueChanged( int );
    void scaleEnabled( bool );
    void locationChanged( Qt::DockWidgetArea area );

  private:
    QgsTileScaleWidget( QgsMapCanvas *mapCanvas, QWidget *parent = nullptr, Qt::WindowFlags f = nullptr );
    ~QgsTileScaleWidget() override = default;

    QgsMapCanvas *mMapCanvas = nullptr;
    QList<double> mResolutions;
};

#endif // QGSTILESCALEWIDGET

==> qgis_3.22.16+dfsg.orig.tar.xz: qgis-3.22.16/src/providers/wms/qgstilescalewidget.h <==
/***************************************************************************
    qgstilescalewidget.cpp  - slider to choose wms-c resolutions
                             -------------------
    begin    : 28 Mar 2010
    copyright: (C) 2010 Juergen E. Fischer < jef at norbit dot de >

 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QGSTILESCALEWIDGET_H
#define QGSTILESCALEWIDGET_H

#include "ui_qgstilescalewidgetbase.h"

class QgsMapCanvas;
class QgsMapLayer;
class QMainWindow;

class QgsTileScaleWidget : public QWidget, private Ui::QgsTileScaleWidget
{
    Q_OBJECT

  public:
    static void showTileScale( QMainWindow *mainWindow );

  public slots:
    void layerChanged( QgsMapLayer *layer );
    void scaleChanged( double );
    void mSlider_valueChanged( int );
    void scaleEnabled( bool );
    void locationChanged( Qt::DockWidgetArea area );

  private:
    QgsTileScaleWidget( QgsMapCanvas *mapCanvas, QWidget *parent = nullptr, Qt::WindowFlags f = Qt::WindowFlags() );
    ~QgsTileScaleWidget() override = default;

    QgsMapCanvas *mMapCanvas = nullptr;
    QList<double> mResolutions;
};

#endif // QGSTILESCALEWIDGET
